import { ErrorHandler, NgModule } from '@angular/core';

import { AppComponent } from './app.component';
import { HomeComponent } from './home/home.component';
import { RegisterComponent } from './register/register.component';

import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { AppRoutingModule } from '@app/app-routing.module';
import { AngularFireModule } from '@angular/fire';
import { AngularFireDatabaseModule } from '@angular/fire/database';
import { AngularFireAuthModule } from '@angular/fire/auth';
import { AppMaterialModule } from '@app/app-material.module';

import { LogService, SEOService } from '@app/core/services';
import {
  AgendaService,
  DayService,
  DragAndDropService,
  MonthAgendaService,
  MonthService,
  ResizeService,
  ScheduleModule,
  TimelineMonthService,
  TimelineViewsService,
  WeekService,
  WorkWeekService
} from '@syncfusion/ej2-angular-schedule';
import { GlobalErrorHandler } from '@app/core/global-error-handler/global-error-handler.service';

import { environment } from '@env/environment';
import { CardComponent } from './card/card.component';
import { SearchCardComponent } from './search-card/search-card.component';
import { MyScheduleComponent } from './my-schedule/my-schedule.component';
import { ActivitiesComponent } from './activities/activities.component';
import { AngularFirestore } from '@angular/fire/firestore';
import { MatDialogModule } from '@angular/material';

@NgModule( {
  declarations: [
    AppComponent,
    HomeComponent,
    RegisterComponent,
    CardComponent,
    SearchCardComponent,
    ActivitiesComponent,
    MyScheduleComponent,
  ],
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    AppRoutingModule,
    AngularFireModule.initializeApp( environment.firebaseConfig ),
    AngularFireAuthModule,
    AngularFireDatabaseModule,
    AppMaterialModule,
    MatDialogModule,
    ScheduleModule,
  ],
  providers: [
    AngularFirestore,
    LogService,
    SEOService,
    AgendaService,
    DayService,
    WeekService,
    WorkWeekService,
    MonthService,
    DragAndDropService,
    MonthAgendaService,
    ResizeService,
    TimelineViewsService,
    TimelineMonthService,
    {
      provide: ErrorHandler,
      useClass: GlobalErrorHandler,
    },
  ],
  bootstrap: [ AppComponent ]
} )
export class AppModule {
}
